@@ -1,5 +1,6 @@
 /**
  * Copyright (c) 2004-2007 Michael Terry
+ * Copyright (c) 2009 Paul Ivanov
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -175,3 +176,11 @@ xpad_pad_group_show_all (XpadPadGroup *group)
 		g_slist_foreach (group->priv->pads, (GFunc) gtk_widget_show, NULL);
 }
 
+
+void
+xpad_pad_group_toggle_hide(XpadPadGroup *group)
+{
+	if (group)
+		g_slist_foreach (group->priv->pads, (GFunc) xpad_pad_toggle, NULL);
+}
+
